#
# spec file for package matio
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define libname lib%{name}
%define major   13
Name:           matio
Version:        1.5.28
Release:        1.1
Summary:        Library for reading and writing MATLAB MAT files
License:        BSD-2-Clause
URL:            https://sourceforge.net/projects/matio/
Source0:        https://downloads.sourceforge.net/matio/%{name}-%{version}.tar.gz
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(zlib) >= 1.2.3

%description
matio is an open-source library for reading and writing MATLAB MAT files.
This library is designed for use by programs/libraries that do not have
access or do not want to rely on MATLAB's shared library.

%package     -n %{libname}%{major}
Summary:        Library for reading and writing MATLAB MAT files
# Avoid unresolvable errors from multiple providers
Requires:       libhdf5

%description -n %{libname}%{major}
matio is an open-source library for reading and writing MATLAB MAT files.
This library is designed for use by programs/libraries that do not have
access or do not want to rely on MATLAB's shared library.

%package     -n %{libname}-devel
Summary:        Development files for %{name}
Requires:       %{libname}%{major} = %{version}
Requires:       hdf5-devel
Requires:       pkgconfig
BuildRequires:  pkgconfig(zlib) >= 1.2.3

%description -n %{libname}-devel
matio is an open-source library for reading and writing MATLAB MAT files.
This library is designed for use by programs/libraries that do not have
access or do not want to rely on MATLAB's shared library.

%package        tools
Summary:        Command line tools for %{name}
Requires:       %{libname}%{major} = %{version}
# Avoid unresolvable errors from multiple providers
Requires:       libhdf5

%description    tools
matio is an open-source library for reading and writing MATLAB MAT files.
This library is designed for use by programs/libraries that do not have
access or do not want to rely on MATLAB's shared library.

%prep
%setup -q

%build
%configure \
  --enable-shared \
  --disable-static \
  --enable-mat73=yes \
  --enable-extended-sparse=yes
%make_build

%install
%make_install
find %{buildroot}%{_libdir} -name '*.la' -type f -delete -print

%check
export LD_LIBRARY_PATH=%{_buildroot}/%{libdir}
%make_build check

%ldconfig_scriptlets -n %{libname}%{major}

%files -n %{libname}%{major}
%license COPYING
%doc NEWS README
%{_libdir}/libmatio.so.%{major}*

%files tools
%{_bindir}/matdump

%files -n %{libname}-devel
%{_includedir}/matio.h
%{_includedir}/matio_pubconf.h
%{_libdir}/libmatio.so
%{_libdir}/pkgconfig/matio.pc
%{_mandir}/man3/Mat_*.3.*

%changelog
* Sat Dec 21 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.28:
  * Fixed bug writing MAT_T_INT8/MAT_T_UINT8 encoded character
    array to compressed v5 MAT file (regression of v1.5.12).
  * Fixed bug reading all-zero sparse array of v4 MAT file
    (regression of v1.5.18).
  * Updated C99 snprintf.c.
  * CMake: Enabled testing.
  * Several other fixes, for example for access violations in
    Mat_VarPrint.
- Drop BuildRequire: p7zip as upstream now uses tar.gz sources
  instead.
- Run make check with multiple threads.
- Minor specfile cleanups (e.g. use standard macros where
  possible).
- Drop no longer needed specfile hackery.
* Sun May 26 2024 jun wang <jgwang@suse.com>
- Update to version 1.5.27
  * Fixed const-correctness of input arguments of API functions
  * Fixed const-correctness of return type of Mat_GetDir
  * Fixed bug duplicating function class (with deep copy) in
    Mat_VarDuplicate
  * Fixed little endian detection for __aarch64__
  * Fixed LFS support on MinGW 64-bit builds
  * Fixed support of Unicode filenames on Windows
  * Fixed detection of HDF5 version for UTF-8 based file name of
    HDF5 MAT file
  * Fixed stack-based buffer overflow when reading (crafted) HDF5
    MAT file
  * Fixed build on Solaris
  * Fixed build with Rust bindings and LLVM >= 16
  * CMake: Fixed MinGW linker error with libc
    (regression of v1.5.24)
  * CMake: Enabled static analysis with Cppcheck
* Wed Nov 22 2023 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.26:
  * Fixed testsuite (regression of v1.5.25)
- Changes from version 1.5.25:
  * Fixed reading struct array with null padded class name from
    HDF5 MAT file
  * Fixed memory leak in Mat_VarFree for function class
- Changes from version 1.5.24:
  * Added predicated iteration API functions
    Mat_VarReadNextInfoPredicate and Mat_VarReadNextPredicate to
    speed-up reading variables from HDF5 MAT file
  * Added new API function Mat_GetFileAccessMode to retrieve the
    file access mode of a MAT file
  * Changed: Mat_VarDelete returns error if MAT file is opened in
    read-only mode
  * Changed: Reduced memory foot-print of matvar_t.internal
  * Fixed read performance of cell/struct array from HDF5 MAT file
  * Fixed reference counting of HDF5 MAT file in Mat_VarDuplicate
  * Fixed file access mode of created v4 MAT file
  * Fixed read performance of Mat_GetDir for HDF5 MAT file
  * Fixed bug reading struct array from v5 MAT file
  * Fixed bug adding field to struct array of v5 MAT file
  * Fixed heap-based buffer overflow when reading HDF5 MAT file
  * Confirmed compatibility with HDF5 v1.14.x
  * autoconf: Enabled system extensions
  * autoconf: Fixed getopt_long check
  * autoconf: Fixed pkg-config file for static linking
  * CMake: Updated cmake-conan to version 0.18.1
  * CMake: Fixed version comparison
  * CMake: Fixed properties for CMake < 3.11
  * CMake: Fixed linker error on OpenBSD
  * CMake: Fixed checks of linker options
  * Several other fixes, for example for memory leaks
- Drop explicit hdf5-devel dependency: we have hdf5 > 1.10 by
  default anyway in Factory.
* Fri May  6 2022 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.23:
  * Fixed testsuite regression from version 1.5.22.
- Changes from version 1.5.22:
  * Added support for reading large MAT file.
  * Updated cmake-conan to version 0.17.0.
  * Fixed CMake build with Conan (MATIO_USE_CONAN:BOOL=ON).
  * Fixed data type when reading 16-bit character data from HDF5
    MAT file.
  * Fixed heap-based buffer overflows when reading (crafted) MAT
    file (CVE-2020-36428, CVE-2021-36977, boo#1193873,
    boo#1193874).
  * Confirmed compatibility with HDF5 v1.13.0 and v1.13.1.
  * Several other fixes, for example for memory leaks.
* Tue Jun  1 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- Update to version 1.5.21
  * Fixed: Avoid usage of strlen when creating MAT_T_UTF8 encoded
    character array
  * Fixed reading of compression flag from HDF5 MAT file
- Use https for URL and SourceURL
* Mon Mar 22 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.20:
  * Added support for writing MAT_T_UTF8 encoded character array
    to HDF5 MAT file (by conversion to UTF-16 if in BMP).
  * Updated cmake-conan to v0.16.1.
  * Fixed bug with size_t arguments of logging function calls.
  * Fixed bug reading past EOF from (crafted) MAT file.
  * Fixed bug writing MAT_T_UTF8 encoded character array to v5 MAT
    file.
  * Fixed printing of MAT_T_UTF8 encoded character array.
  * Several other fixes, for example for memory leaks.
* Sun Nov 15 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.19:
  * Fixed support for CMake (>= v3.19.0) build system.
  * Fixed bug reading variable from v4 MAT file (regression of
    v1.5.18).
* Sat Sep 19 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.18:
  * Added support of HDF5 v1.12.x.
  * Added support for reading uncompressed v5 MAT file generated
    by SWAN.
  * Added error codes to public interface.
  * Added support for CMake build system.
  * Fixed read performance of numeric array from compressed v5 MAT
    file.
  * Fixed support for VS2005 and VS2008 (MSVC) (regression of
    v1.5.15).
  * Fixed mktemp linker warning when using GNU linker.
  * Fixed bug writing struct array to uncompressed v5 MAT file on
    big endian architecture (regression of v1.5.10).
  * Fixed bug writing cell array to uncompressed v5 MAT file on
    big endian architecture.
  * Fixed bug reading variable name from v4 MAT file
    (CVE-2019-17533).
  * Fixed bug reading dimensions from (crafted) compressed v5 MAT
    file (CVE-2019-20017, CVE-2019-20018, CVE-2019-20020,
    CVE-2019-20052).
- Bump soversion to 11.
* Sat Feb 22 2020 Max Lin <mlin@suse.com>
- Leap 15.2 has newer p7zip, build requires p7zip-full on Tumbleweed,
  Leap 15.2 and SLE15 SP2.
* Fri Sep 20 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 1.5.17
  * Fixed bug reading struct array with packed field names from v5
    MAT file
  * Fixed bug reading past EOF from (crafted) uncompressed v5 MAT
    file
- Drop 0001-Write-backwards-compatible-Mat7.3-files.patch:
  incorporated upstream.
- Update so number to 9 in keeping with upstream.
* Thu Oct  4 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix preprocessor check for availability of H5F_LIBVER_V18
* Tue Oct  2 2018 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Force writing of backwards compatible files with HDF5 1.10.x
  0001-Write-backwards-compatible-Mat7.3-files.patch
  (gh#tbeu/matio#93).
* Fri Jun 29 2018 stefan.bruens@rwth-aachen.de
- BuildRequire p7zip-full instead of p7zip on TW, 7za was moved
  from p7zip to the new package, breaking backwards compatibility.
- use %%license for COPYING
* Thu Apr 12 2018 adrian@suse.de
- enforce hdf5 1.8 to ensure that files can still be exchanged
* Tue Apr  3 2018 jengelh@inai.de
- Fix SRPM group. Trim redundant wording from summaries.
* Sat Mar 31 2018 stefan.bruens@rwth-aachen.de
- Update to version 1.5.12:
  * Updated Mat_VarWriteAppend: Added support to append a variable
    to a previously written struct array in HDF5 MAT file
  * Fixed bug reading MAT_T_UINT16 encoded character array from
    HDF5 MAT file
  * Fixed bug reading MAT_T_UTF16 encoded character array from
    compressed v5 MAT file
  * Fixed bug writing MAT_T_UTF16 encoded character array to HDF5
    MAT file
  * Fixed buffer overflow in Mat_VarGetCells/Mat_VarGetStructs
- Reenable support for Mat v7.3
- Use significantly smaller 7z compressed sources (2.7 vs 10 MByte)
* Thu Oct 26 2017 badshah400@gmail.com
- Update to version 1.5.11:
  * Added new API function Mat_VarWriteAppend to append a numeric
    array to a previously written variable in HDF5 MAT file.
  * Fixed bug calculating sizes of cell/struct array with empty
    cells/fields in Mat_VarGetSize.
  * Fixed bug writing cell/struct array with empty cells/fields to
    v5 MAT file.
  * Fixed bug writing cell/struct array with empty cells/fields to
    HDF5 MAT file.
  * Fixed read performance of cell/struct array with empty
    cells/fields from v5 MAT file.
  * Fixed read performance of numeric array from uncompressed v5
    MAT file.
  * Fixed testsuite (if configured with the MATLAB application).
  * Updated man pages.
- Drop BuildRequires: libtool and the autoreconf run before
  configure; the patches that needed these have been long gone.
- Mat v7.3 tests fail, so turn off enable-mat73 for now.
* Mon Oct  2 2017 badshah400@gmail.com
- Update to version 1.5.10:
  * Added new API function Mat_GetDir to retrieve all variable
    names of a MAT file
  * Fixed performance of repeated calls to Mat_VarWrite (broken by
    v1.5.7)
  * Fixed bugs reading (hyperslabs of) numeric arrays where the
    variable data type differs from the desired output data type
  * Increased testsuite coverage
* Mon Oct 24 2016 dmitry_r@opensuse.org
- Update to version 1.5.9
  * Bug fixes
  * HDF5 1.10 support, drop obsolete matio-hdf5_110-support.patch
    matio-disable-failing-hdf5-tests.patch
* Fri Aug  5 2016 badshah400@gmail.com
- Add matio-hdf5_110-support.patch to fix support for
  hdf5 >= 1.10; patch taken from upstream git (gh#tbeu/matio#37).
- Add matio-disable-failing-hdf5-tests.patch to disable "mat73"
  tests that fail (apparently) due to bugs in hdf5 1.10
  (gh#tbeu/matio#41); patch touches autotool files, add
  BuildRequires on libtool and run "autoreconf -fi" before
  configure.
* Fri Jul  8 2016 dmitry_r@opensuse.org
- Update to version 1.5.8
  * Bug fixes
* Thu Jun 23 2016 dmitry_r@opensuse.org
- Update to version 1.5.7
  * Added support for MAT_T_UTF16 when reading character array from v5 MAT file
  * Added support of HDF5 v1.10.x (with deprecated v1.8.x symbols exported)
  * Added warning on unsupported character data types when reading v5 MAT file
  * Added error check if variable already exists when writing to MAT file
  * Bug fixes
* Mon Mar 21 2016 dmitry_r@opensuse.org
- Update to version 1.5.6
  * Added support of reading sparse array from v4 MAT files
  * Added support of writing sparse array to v4 MAT files
  * Added support of writing character array to v4 MAT files
  * Bug fixes
* Wed Feb  3 2016 dmitry_r@opensuse.org
- Update to version 1.5.3
  * Added support for writing numeric arrays to v4 MAT files
  * Added new API functions Mat_CalcSingleSubscript2 and Mat_CalcSubscripts2 that
  work on size_t type
  * Bug fixes
* Mon Aug 31 2015 toddrme2178@gmail.com
- Avoid unresolvable errors from multiple providers of libhdf5
* Thu Aug  1 2013 dmitry_r@opensuse.org
- Update to version 1.5.2
  * Added support for linear data read for v4 and HDF5 MAT files
  * Fixed bug reading slices of variables in matdump
  * Fix feof calls so they compile on platforms that dereference
  the argument in a macro
  * More robust checking that file is MAT file and eliminates some
  segmentation faults
  * Various fixes for unused variables, unnecessary initializations,
  etc. that cause compilers to issue diagnostices
  * Several other fixes
* Sun Mar 10 2013 dmitry_r@opensuse.org
- Update to version 1.5.1
  * Fix bug writing compressed HDF5 files
  * Fix bug reading cell array elements written with a non-empty
    variable name
  * Fix bug writing complex sparse matrices as struct fields or
    cell elements to uncompressed v5 MAT files
  * Fix a number of potential issues identified via static analysis
  * Fix uninitialized pointers when creating structures through
    Mat_VarCreateStruct, and fix a bug in the struct API testsuite
  * Fix extended sparse support in v7.3 MAT files and add 64-bit
    integer support for v5 MAT files
  * Add missing support for reading hyperslabs from HDF5 MAT files
  * Added variable indexing notation support to matdump to display
    subsets of variables
  * Added tests for extended sparse support in testsuite
  * Add missing enumerations or default case in switch statements
  * removed obsolete gcc-warnings-fix.patch
  * removed obsolete matvar_struct.patch
  * removed obsolete mat4_bigendian.patch
* Thu Dec 20 2012 dvaleev@suse.com
- Fix Big Endian issues in mat4. (mat4_bigendian.patch)
* Thu Dec 20 2012 dvaleev@suse.com
- Fix failing 684 686 test (matvar_struct.patch)
* Fri Aug 17 2012 toddrme2178@gmail.com
- Various spec file cleanups
* Thu Aug 16 2012 dmitry_r@opensuse.org
- update to version 1.5.0
  * Support for reading/writing HDF5 format MAT files
  * Bug fixes for compressed variables that caused issues with
  matio reading them.
  * Upgrade of dimensions in matvar_t structure to size_t enabling
  support for large arrays.
  * A testsuite
- add gcc-warnings-fix.patch: fix implicit declaration
- remove libmatio0-1.3.3-doxygen.patch: now matio doesn't use
  doxygen
* Wed Jun 27 2012 scorot@free.fr
- fix documentation build thanks to a patch from debian
- spec file reformating and cleanup
